/**
 * The MIT License (MIT)
 *
 * Copyright (C) 2013 Jaroslav Tulach <jaroslav.tulach@apidesign.org>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */
package org.apidesign.html.chatserver.model;

import net.java.html.json.ComputedProperty;
import net.java.html.json.Model;
import net.java.html.json.Property;

/** Generic model of communication between browser and a chat server.
 * The same code is then used on the server, on the client and even in unit 
 * tests.
 * 
 * @author Jaroslav Tulach <jaroslav.tulach@apidesign.org>
 */
@Model(className = "Message", properties = {
    @Property(name = "user", type = String.class),
    @Property(name = "comment", type = String.class),
    @Property(name = "since", type = long.class)    
})
class MessageImpl {
    @ComputedProperty static String at(long since) {
        long delta = since / 1000;
        if (delta <= 0) {
            return "Boot-time";
        }
        if (delta < 60) {
            return delta + "s";
        }
        delta /= 60;
        return delta + "min";
    }

    @Model(className = "Query", properties = {
        @Property(name = "messages", type = Message.class, array = true)
    })
    class QryMsgs {
    }
}
